/**
 * The contents of this file are licensed under the terms of the Apache
 * License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT 
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the 
 * License for the specific language governing permissions and limitations 
 * under the License.
 * 
 * Please see the NOTICE file for copyright information.
 */

package com.foogod.btroutefix;

import android.app.Activity;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

public class ControlActivity extends Activity {
	public static final String LOG_TAG = "BTRouteFix";

	TextView mStatusView;
	Button mButtonView;
	SharedPreferences mPrefs;
	SharedPreferences.Editor mPrefsEditor;

	View.OnClickListener mButtonListener = new View.OnClickListener() {
		@Override
		public void onClick(View v) {
			toggleState();
		}
	};
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		try {
			super.onCreate(savedInstanceState);
			setContentView(R.layout.controlscreen);
			mStatusView = (TextView)findViewById(R.id.status);
			mButtonView = (Button)findViewById(R.id.button);
			mButtonView.setOnClickListener(mButtonListener);
			mPrefs = PreferenceManager.getDefaultSharedPreferences(this);
            mPrefsEditor = mPrefs.edit();
            checkState();
		} catch (RuntimeException ex) {
			Log.e(LOG_TAG, "onCreate exception: ", ex);
			throw ex;
		}
	}

	void toggleState() {
		boolean enabled = mPrefs.getBoolean("enabled", true);
		mPrefsEditor.putBoolean("enabled", !enabled);
		mPrefsEditor.commit();
		checkState();
	}
	
	void checkState() {
		boolean enabled = mPrefs.getBoolean("enabled", true);
		if (enabled) {
			startService(new Intent(this, RouteFixService.class));
			mStatusView.setText(R.string.status_enabled);
			mStatusView.setTextColor(getResources().getColor(R.color.status_enabled));
			mButtonView.setText(R.string.button_disable);
		} else {
			stopService(new Intent(this, RouteFixService.class));
			mStatusView.setText(R.string.status_disabled);
			mStatusView.setTextColor(getResources().getColor(R.color.status_disabled));
			mButtonView.setText(R.string.button_enable);
		}
	}
}
